Class: MfkOpenapiRubyClient::CustomerPayload
- Inherits:
-
Object
- Object
- MfkOpenapiRubyClient::CustomerPayload
- Defined in:
- lib/mfk_openapi_ruby_client/models/customer_payload.rb
Overview
顧客登録情報です。顧客登録時に利用します。顧客には必ず一つの請求先が必要であるため同時に請求先一件も登録します。
Instance Attribute Summary collapse
-
#customer_examination ⇒ Object
Returns the value of attribute customer_examination.
-
#destination ⇒ Object
Returns the value of attribute destination.
-
#name ⇒ Object
顧客名です。.
-
#number ⇒ Object
顧客に付与できる任意の顧客番号です。Money Forward Kessaiが発番する顧客IDをとは別で、売り手様が独自に管理する識別子を登録することができます。 ただし、売り手様の所有する顧客間で一意である必要があります。.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomerPayload
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CustomerPayload
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 62 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `MfkOpenapiRubyClient::CustomerPayload` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `MfkOpenapiRubyClient::CustomerPayload`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'destination') self.destination = attributes[:'destination'] end if attributes.key?(:'customer_examination') self.customer_examination = attributes[:'customer_examination'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'number') self.number = attributes[:'number'] end end |
Instance Attribute Details
#customer_examination ⇒ Object
Returns the value of attribute customer_examination.
21 22 23 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 21 def customer_examination @customer_examination end |
#destination ⇒ Object
Returns the value of attribute destination.
19 20 21 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 19 def destination @destination end |
#name ⇒ Object
顧客名です。
24 25 26 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 24 def name @name end |
#number ⇒ Object
顧客に付与できる任意の顧客番号です。Money Forward Kessaiが発番する顧客IDをとは別で、売り手様が独自に管理する識別子を登録することができます。 ただし、売り手様の所有する顧客間で一意である必要があります。
27 28 29 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 27 def number @number end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 40 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 30 def self.attribute_map { :'destination' => :'destination', :'customer_examination' => :'customer_examination', :'name' => :'name', :'number' => :'number' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
202 203 204 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 202 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 55 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 45 def self.openapi_types { :'destination' => :'CustomerPayloadDestination', :'customer_examination' => :'CustomerPayloadCustomerExamination', :'name' => :'String', :'number' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 178 def ==(o) return true if self.equal?(o) self.class == o.class && destination == o.destination && customer_examination == o.customer_examination && name == o.name && number == o.number end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 232 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = MfkOpenapiRubyClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 303 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 209 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
189 190 191 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 189 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
195 196 197 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 195 def hash [destination, customer_examination, name, number].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 94 def list_invalid_properties invalid_properties = Array.new if @destination.nil? invalid_properties.push('invalid value for "destination", destination cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 50 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 50.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.') end if @number.nil? invalid_properties.push('invalid value for "number", number cannot be nil.') end if @number.to_s.length > 100 invalid_properties.push('invalid value for "number", the character length must be smaller than or equal to 100.') end if @number.to_s.length < 1 invalid_properties.push('invalid value for "number", the character length must be great than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
279 280 281 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 279 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 285 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
273 274 275 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 273 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
129 130 131 132 133 134 135 136 137 138 |
# File 'lib/mfk_openapi_ruby_client/models/customer_payload.rb', line 129 def valid? return false if @destination.nil? return false if @name.nil? return false if @name.to_s.length > 50 return false if @name.to_s.length < 1 return false if @number.nil? return false if @number.to_s.length > 100 return false if @number.to_s.length < 1 true end |